## How to use the notebooks in this folder

This folder contains Jupyter notebooks that interact with `timelink`.

In order to use the notebooks you need to install VSCode, the Python interpreter and support libraries.

You also need to install Docker.

1. Install VSCode from https://code.visualstudio.com/download
2. Install the Python VSCode extension from  https://marketplace.visualstudio.com/items?itemName=ms-python.python
3. After restarting VS Code and set up your environment as instructed in step 2, install the support libraries:##
   * cmp+shift+P Python create environment https://code.visualstudio.com/docs/python/environments
   * choose Python interpreter from list
   * accept suggestion to install notebooks/requirements.txt
4. Install jupyter extension
5. Open notebook [00-tutorial-index.ipynb]
6. in the upper right corner select the environment you just created
7. Install Docker. See https://docs.docker.com/get-docker/

See the notebook [0.tutorial](tests/timelink-home/projects/test-project/notebooks/0.tutorial.ipynb) for a tutorial on how to use `timelink` in a notebook.

If you have problems create an issue or start a discussion in https://github.com/time-link/timelink-py

## Install Docker

Go to https://www.docker.com/products/docker-desktop/

And install the version for your system.

